@@ -116,6 +116,53 @@ def shutdown_docker_config(
     return True
 
 
+def patch_docker_config(
+    config: DockerConfig,
+    name_filter: Optional[str] = None,
+    type_filter: Optional[str] = None,
+    dry_run: Optional[bool] = False,
+) -> bool:
+
+    # Step 1: Get the DockerManager
+    docker_manager: DockerManager = config.get_docker_manager()
+    if docker_manager is None:
+        raise DockerConfigException("DockerManager unavailable")
+
+    # Step 2: If dry_run, print the resources and return True
+    if dry_run:
+        docker_manager.patch_resources_dry_run(
+            name_filter=name_filter, type_filter=type_filter
+        )
+        return True
+
+    # Step 3: Patch resources
+    env = config.env
+    print_subheading(
+        "Patching docker config{}\n".format(
+            f" for env: {env}" if env is not None else ""
+        )
+    )
+    try:
+        success: bool = docker_manager.patch_resources(
+            name_filter=name_filter, type_filter=type_filter
+        )
+        if not success:
+            return False
+    except Exception:
+        raise
+
+    # Step 4: Validate resources are patched
+    resources_patch_valid: bool = docker_manager.validate_resources_are_deleted(
+        name_filter=name_filter, type_filter=type_filter
+    )
+    if not resources_patch_valid:
+        logger.error("DockerResource patch could not be validated")
+        return False
+
+    print_info("Docker config patch")
+    return True
+
+
 def run_workflows_docker(
     workflow_file: str,
     workflows: Dict[str, Workflow],
