@@ -17,7 +17,7 @@ class WorkspaceEnv(ExtendedEnum):
     prd = "prd"
 
 
-class WorkspaceInfra(ExtendedEnum):
+class WorkspaceConfigType(ExtendedEnum):
     docker = "docker"
     k8s = "k8s"
     gcp = "gcp"
